@@ -182,21 +182,31 @@ class DepositIntegration:
         """
         Use this function to process the data collected with `form` and to update
         the state of the interactive flow so that the next call to
-        ``DepositIntegration.form_for_transaction`` returns the next form to render
-        to the user, or returns None.
-
-        Keep in mind that if a ``TransactionForm`` is submitted, Polaris will
-        update the `amount_in` and `amount_fee` with the information collected.
-        There is no need to implement that yourself.
-
-        DO NOT update `transaction.status` here or in any other function for
-        that matter. This column is managed by Polaris and is expected to have
-        particular values at different points in the flow.
+        ``DepositIntegration.form_for_transaction()`` returns the next form to render
+        to the user.
 
         If you need to store some data to determine which form to return next when
         ``DepositIntegration.form_for_transaction`` is called, store this
         data in a model not used by Polaris.
 
+        Keep in mind that if a ``TransactionForm`` is submitted, Polaris will
+        update the ``Transaction.amount_in``, ``Transaction.amount_fee``, and
+        ``Transaction.amount_out`` fields with the information collected. There is no
+        need to implement that yourself here. However, note that if the amount
+        ultimately delivered to the anchor does not match the amount specified in
+        the form, these attributes must be updated appropriately.
+
+        If `form` is the last form to be served to the user, Polaris will update the
+        transaction status to ``pending_user_transfer_start``, indicating that the
+        anchor is waiting for the user to deliver off-chain funds to the anchor. If
+        the KYC information collected is still being verified, update the
+        ``Transaction.status`` column to ``pending_anchor`` here. Make sure to save
+        this change to the database before returning. In this case Polaris will
+        detect the status change and will not update the status again. Polaris will
+        wait until the anchor changes the transaction's status to
+        ``pending_user_transfer_start`` before including the transaction in calls to
+        ``DepositIntegration.poll_pending_deposits()``.
+
         :param form: the completed ``forms.Form`` submitted by the user
         :param transaction: the ``Transaction`` database object
         """
@@ -290,6 +300,14 @@ class DepositIntegration:
         if you plan to return a success response. If `transaction` is saved to the DB but a
         failure response is returned, Polaris will return a 500 error to the user.
 
+        If you'd like the user to send ``Transaction.amount_in`` `plus the fee amount`,
+        add the amount charged as a fee to ``Transaction.amount_in`` here. While not
+        required per SEP-6, it is encouraged to also populate ``Transaction.amount_fee``
+        and ``Transaction.amount_out`` here as well. Note that the amount sent over the
+        Stellar Network could differ from the amount specified in this API call, so fees
+        and the amount delievered may have to be recalculated in
+        ``RailsIntegration.execute_outgoing_transaction()``.
+
         Polaris responds to requests with the standard status code according the SEP. However,
         if you would like to return a custom error code in the range of 400-599 you may raise
         an ``rest_framework.exceptions.APIException``. For example, you could return a 503
@@ -374,6 +392,41 @@ class DepositIntegration:
         """
         pass
 
+    def patch_transaction(self, params: Dict, transaction: Transaction):
+        """
+        .. _`GET /info response`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#response-2
+        .. _`GET /deposit`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#deposit
+        .. _`GET /transactions`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#transaction-history
+        .. _`PATCH /transactions`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0006.md#update
+
+        Currently only used for SEP-6 transactions.
+
+        The `GET /info response`_ contains a `fields` object that describes the custom fields
+        an anchor requires in requests to the `GET /deposit`_ endpoint. If one or more of these fields
+        were originally accepted but later discovered to be invalid in some way, an anchor can place
+        the transaction in the ``pending_transaction_info_update`` status, save a JSON-serialized
+        object describing the fields that need updating to ``Transaction.required_info_updates``,
+        and save a human-readable message to ``Transaction.required_info_message`` describing the
+        reason the fields need to be updated. A client can make a request to `GET /transactions`_ to
+        detect that updated information is needed.
+
+        This function is called when SEP-6 `PATCH /transactions`_ requests are made by the client to
+        provide the updated values described in the ``Transaction.required_info_updates``. Use the
+        `params` passed in the request to update `transaction` or any related data.
+
+        Polaris validates that every field listed in ``Transaction.required_info_updates`` is
+        present in `params` but cannot validate the values. If a ``ValueError`` is raised, Polaris
+        will return a 400 response containing the exception message in the body.
+
+        If no exception is raised, Polaris assumes the update was successful and will update the
+        transaction's status back to ``pending_anchor`` as well as clear the ``required_info_updates``
+        and ``required_info_message`` fields.
+
+        :param params: The request parameters as described in the `PATCH /transactions`_ endpoint.
+        :param transaction: A ``Transaction`` object for which updated was provided.
+        """
+        raise NotImplementedError("PATCH /transactions/:id is not supported")
+
 
 class WithdrawalIntegration:
     """
@@ -493,7 +546,7 @@ class WithdrawalIntegration:
                 }
             }
 
-        In addition to this response, uou may also return the `Customer information needed`_
+        In addition to this response, you may also return the `Customer information needed`_
         and `Customer Information Status`_ responses as described in
         ``DepositIntegration.process_sep6_request``.
         """
@@ -501,6 +554,12 @@ class WithdrawalIntegration:
             "`process_sep6_request` must be implemented if SEP-6 is active"
         )
 
+    def patch_transaction(self, params: Dict, transaction: Transaction):
+        """
+        Same as ``DepositIntegration.patch_transaction``
+        """
+        raise NotImplementedError("PATCH /transactions/:id is not supported")
+
 
 registered_deposit_integration = DepositIntegration()
 registered_withdrawal_integration = WithdrawalIntegration()
